@@ -37,7 +37,7 @@ def review(openai_key, assistant_id, token, repo, branch, message, gh_before, sh
             '--item', item, 
             '--openai-key', openai_key, 
             '--assistant-id', assistant_id,
-            '--mode', 'testing',
+            # '--mode', 'testing',
         ]).decode('utf-8')
     except subprocess.CalledProcessError as e:
         print(f"Error running cururo: {e}")
